@@ -63,7 +63,6 @@ class AxiLiteSlaveWrite(Reset):
         self.wstrb_present = hasattr(self.bus.w, "wstrb")
 
         self.log.info("AXI lite slave model configuration:")
-        self.log.info("  Memory size: %d bytes", len(self.mem))
         self.log.info("  Address width: %d bits", self.address_width)
         self.log.info("  Byte size: %d bits", self.byte_size)
         self.log.info("  Data width: %d bits (%d bytes)", self.width, self.byte_lanes)
@@ -107,7 +106,7 @@ class AxiLiteSlaveWrite(Reset):
             aw = await self.aw_channel.recv()
 
             addr = (int(aw.awaddr) // self.byte_lanes) * self.byte_lanes
-            prot = AxiProt(getattr(aw, 'awprot', AxiProt.NONSECURE))
+            prot = AxiProt(int(getattr(aw, 'awprot', AxiProt.NONSECURE)))
 
             w = await self.w_channel.recv()
 
@@ -182,7 +181,6 @@ class AxiLiteSlaveRead(Reset):
         self.byte_lanes = self.width // self.byte_size
 
         self.log.info("AXI lite slave model configuration:")
-        self.log.info("  Memory size: %d bytes", len(self.mem))
         self.log.info("  Address width: %d bits", self.address_width)
         self.log.info("  Byte size: %d bits", self.byte_size)
         self.log.info("  Data width: %d bits (%d bytes)", self.width, self.byte_lanes)
@@ -223,7 +221,7 @@ class AxiLiteSlaveRead(Reset):
             ar = await self.ar_channel.recv()
 
             addr = (int(ar.araddr) // self.byte_lanes) * self.byte_lanes
-            prot = AxiProt(getattr(ar, 'arprot', AxiProt.NONSECURE))
+            prot = AxiProt(int(getattr(ar, 'arprot', AxiProt.NONSECURE)))
 
             r = self.r_channel._transaction_obj()
             r.rresp = AxiResp.OKAY
@@ -251,5 +249,5 @@ class AxiLiteSlave:
 
         super().__init__(**kwargs)
 
-        self.write_if = AxiLiteSlaveWrite(target, bus.write, clock, reset, reset_active_level)
-        self.read_if = AxiLiteSlaveRead(target, bus.read, clock, reset, reset_active_level)
+        self.write_if = AxiLiteSlaveWrite(bus.write, clock, reset, target, reset_active_level)
+        self.read_if = AxiLiteSlaveRead(bus.read, clock, reset, target, reset_active_level)
